@@ -256,9 +256,9 @@ class Get_ASM_Consume:
             # 开始计算；
             yes_credits_num  = float(df[(df['账单ID'] == int(self.defOrg_id))].values[0][2])
             if float(today_credits_num) != yes_credits_num:
-                yes_run_num = round(today_credits_num - yes_credits_num, 2)  # 昨日消耗的；
+                yes_run_num = round(yes_credits_num - today_credits_num, 2)  # 昨日消耗的；
                 # now_yue_num = budget_amount - spent_value  # 限制消耗金额减去当前总消耗
-                now_yue_days = int(math.floor(today_credits_num / yes_run_num))  # 预估还可消耗天数；
+                now_yue_days = int(math.floor(yes_run_num / today_credits_num))  # 预估还可消耗天数；
             else:
                 # 如果今日昨日一样，代表没消耗的，就可以跳过；
                 yes_run_num = '空'
